==> lm_deluge-0.0.47.tar.gz: lm_deluge-0.0.47/src/lm_deluge/models/groq.py <==
GROQ_MODELS = {
    "llama-3.1-8b-groq": {
        "id": "llama-3.1-8b-groq",
        "name": "llama-3.1-8b-instant",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "llama-3.3-70b-groq": {
        "id": "llama-3.3-70b-groq",
        "name": "llama-3.3-70b-versatile",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "r1-llama-70b-groq": {
        "id": "r1-llama-70b-groq",
        "name": "deepseek-r1-distill-llama-70b",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "llama-4-maverick-groq": {
        "id": "llama-4-maverick-groq",
        "name": "meta-llama/llama-4-maverick-17b-128e-instruct",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "llama-4-scout-groq": {
        "id": "llama-4-scout-groq",
        "name": "meta-llama/llama-4-scout-17b-16e-instruct",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "kimi-k2-groq": {
        "id": "kimi-k2-groq",
        "name": "moonshotai/kimi-k2-instruct",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "gpt-oss-120b-groq": {
        "id": "gpt-oss-120b-groq",
        "name": "openai/gpt-oss-120b",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
        "reasoning_model": True,
    },
    "gpt-oss-20b-groq": {
        "id": "gpt-oss-20b-groq",
        "name": "openai/gpt-oss-20b",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
        "reasoning_model": True,
    },
    "qwen-3-32b-groq": {
        "id": "qwen-3-32b-groq",
        "name": "qwen/qwen3-32b",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
}

==> lm_deluge-0.0.74.tar.gz: lm_deluge-0.0.74/src/lm_deluge/models/groq.py <==
GROQ_MODELS = {
    "llama-3.1-8b-groq": {
        "id": "llama-3.1-8b-groq",
        "name": "llama-3.1-8b-instant",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "llama-3.3-70b-groq": {
        "id": "llama-3.3-70b-groq",
        "name": "llama-3.3-70b-versatile",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "r1-llama-70b-groq": {
        "id": "r1-llama-70b-groq",
        "name": "deepseek-r1-distill-llama-70b",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "llama-4-maverick-groq": {
        "id": "llama-4-maverick-groq",
        "name": "meta-llama/llama-4-maverick-17b-128e-instruct",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "llama-4-scout-groq": {
        "id": "llama-4-scout-groq",
        "name": "meta-llama/llama-4-scout-17b-16e-instruct",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
    "kimi-k2-groq": {
        "id": "kimi-k2-groq",
        "name": "moonshotai/kimi-k2-instruct-0905",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": True,
        "api_spec": "openai",
    },
    "gpt-oss-120b-groq": {
        "id": "gpt-oss-120b-groq",
        "name": "openai/gpt-oss-120b",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
        "reasoning_model": True,
    },
    "gpt-oss-20b-groq": {
        "id": "gpt-oss-20b-groq",
        "name": "openai/gpt-oss-20b",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
        "reasoning_model": True,
    },
    "qwen-3-32b-groq": {
        "id": "qwen-3-32b-groq",
        "name": "qwen/qwen3-32b",
        "api_base": "https://api.groq.com/openai/v1",
        "api_key_env_var": "GROQ_API_KEY",
        "supports_json": False,
        "api_spec": "openai",
    },
}
